<?php
session_start();
require_once '../../../datab.php';
$res = [];

$today_date = date("Y-m-d");
$floor_id = $_SESSION['floor_id'];

// Default values for pagination and search
$pg_no = isset($_GET['pg_no']) ? (int)$_GET['pg_no'] : 1;
$items_per_page = isset($_GET['items_per_page']) ? (int)$_GET['items_per_page'] : 10; // Items per page (default is 10)
$search = isset($_GET['search']) ? mysqli_real_escape_string($conn, $_GET['search']) : '';

// Calculate the offset
$offset = ($pg_no - 1) * $items_per_page;

// Base SQL query
$sql = "SELECT
            ip_ob_entry_data.*,
            ip_ob_entry_data.id AS op_id,
            ip_ob_entry_data.status AS patient_status,
            b.building_name,
            f.floor_no,
            (f.id) floor_id,
            rooms.room_no,
            beds.bed_name,
            patient_data.id AS pd_id,
            patient_data.patient_name,
            patient_data.mrd_no,
            DATE_FORMAT(ip_ob_entry_data.dateTime, '%d-%b-%Y %h:%i %p') AS ip_dateTime
        FROM
            ip_ob_entry_data
        JOIN
            patient_data ON patient_data.id = ip_ob_entry_data.patient_id
        JOIN
            beds ON beds.id = ip_ob_entry_data.bed_id
        JOIN
            rooms ON rooms.id = beds.room_id
        JOIN
            floor f ON f.id = rooms.floor_id
        JOIN
            building b ON b.id = f.building_id
        WHERE
            ip_ob_entry_data.patient_type IN ('ip', 'observation')
        AND
            ip_ob_entry_data.status NOT IN ('Admitted', 'Allotted', 'Paid') 
        AND 
            f.id = '$floor_id' ";

// Add search functionality
if (!empty($search)) {
    $sql .= " AND (patient_data.patient_name LIKE '%$search%' 
               OR patient_data.mrd_no LIKE '%$search%' 
               OR rooms.room_no LIKE '%$search%' 
               OR beds.bed_name LIKE '%$search%')";
}

// Query to count total records without LIMIT for pagination calculation
$total_count_query = "SELECT COUNT(*) AS total_count FROM ($sql) AS subquery";
$total_count_result = mysqli_query($conn, $total_count_query);
$total_count_row = mysqli_fetch_assoc($total_count_result);
$total_records = $total_count_row['total_count'];

// Calculate total pages
$total_pages = ceil($total_records / $items_per_page);

// Append LIMIT and OFFSET for pagination
$sql .= " LIMIT $items_per_page OFFSET $offset";

if ($result = mysqli_query($conn, $sql)) {
    $data = [];
    while ($row = mysqli_fetch_assoc($result)) {
        $data[] = $row;
    }
    $res['data'] = $data;
    $res['status'] = 'Success';
    $res['remarks'] = 'Data sent';
    $res['total_pages'] = $total_pages;
    $res['current_page'] = $pg_no;
    $res['total_records'] = $total_records;
} else {
    $res['status'] = 'Error';
    $res['remarks'] = 'Error sending data: ' . mysqli_error($conn);
}

echo json_encode($res);
?>
