<?php
session_start();
require_once '../../../datab.php';

header('Content-Type: application/json');

$response = array();

// Check database connection
if ($conn->connect_error) {
    $response['status'] = 'Error';
    $response['message'] = 'Database connection failed: ' . $conn->connect_error;
    echo json_encode($response);
    exit;
}

// Get pagination and search parameters from POST request
$results_per_page = 10; // Number of records per page
$current_page = isset($_POST['pg_no']) ? intval($_POST['pg_no']) : 1;
$search_term = isset($_GET['search']) ? mysqli_real_escape_string($conn, $_GET['search']) : '';

// Calculate offset for the query
$offset = ($current_page - 1) * $results_per_page;
$floor_id = $_SESSION['floor_id'];

// Build the search query part
$search_query = "";
if (!empty($search_term)) {
    $search_query = " AND (patient_data.patient_name LIKE '%$search_term%' OR patient_data.mrd_no LIKE '%$search_term%')";
}

// SQL query to get the total count of matching records
$count_sql = "
    SELECT COUNT(*) AS total_count
    FROM ip_ob_entry_data
    JOIN patient_data ON patient_data.id = ip_ob_entry_data.patient_id
    JOIN beds ON beds.id = ip_ob_entry_data.bed_id
    JOIN rooms ON rooms.id = beds.room_id
    JOIN floor f ON f.id = rooms.floor_id
    JOIN building b ON b.id = f.building_id
    WHERE ip_ob_entry_data.patient_type = 'ip'
      AND ip_ob_entry_data.status <> 'Discharged'
      AND ip_ob_entry_data.status <> 'Paid'
      AND f.id = ?
      $search_query
";

$stmt_count = $conn->prepare($count_sql);
$stmt_count->bind_param('i', $floor_id);

if ($stmt_count->execute()) {
    $result_count = $stmt_count->get_result();
    $total_count = $result_count->fetch_assoc()['total_count'];
    $stmt_count->close();
} else {
    $response['status'] = 'Error';
    $response['message'] = 'Failed to get total count: ' . $conn->error;
    echo json_encode($response);
    exit;
}

// Calculate total pages
$total_pages = ceil($total_count / $results_per_page);

// SQL query to fetch paginated results with search functionality
$sql = "
    SELECT
        ip_ob_entry_data.*,
        ip_ob_entry_data.id AS op_id,
        ip_ob_entry_data.status AS patient_status,
        b.building_name,
        f.floor_no,
        f.id AS floor_id,
        rooms.room_no,
        beds.bed_name,
        patient_data.id AS pd_id,
        patient_data.patient_name,
        patient_data.mrd_no,
        DATE_FORMAT(ip_ob_entry_data.dateTime, '%d-%b-%Y %h:%i %p') AS ip_dateTime
    FROM
        ip_ob_entry_data
    JOIN
        patient_data ON patient_data.id = ip_ob_entry_data.patient_id
    JOIN
        beds ON beds.id = ip_ob_entry_data.bed_id
    JOIN
        rooms ON rooms.id = beds.room_id
    JOIN
        floor f ON f.id = rooms.floor_id
    JOIN
        building b ON b.id = f.building_id
    WHERE
        ip_ob_entry_data.patient_type = 'ip'
      AND
        ip_ob_entry_data.status <> 'Discharged'
      AND
        ip_ob_entry_data.status <> 'Paid'
      AND
        f.id = ?
      $search_query
    ORDER BY
        ip_ob_entry_data.dateTime DESC
    LIMIT ?, ?
";

$stmt = $conn->prepare($sql);
$stmt->bind_param('iii', $floor_id, $offset, $results_per_page);

if ($stmt->execute()) {
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        $rows = array();
        while ($row = $result->fetch_assoc()) {
            $rows[] = $row;
        }
        $response['status'] = 'Success';
        $response['data'] = $rows;
        $response['total_count'] = $total_count;
        $response['total_pages'] = $total_pages;
        $response['current_page'] = $current_page;
    } else {
        $response['status'] = 'Error';
        $response['message'] = 'No records found.';
    }

    $stmt->close();
} else {
    $response['status'] = 'Error';
    $response['message'] = 'Query preparation failed: ' . $conn->error;
}

// Close connection
$conn->close();

// Output JSON response
echo json_encode($response);
?>
